#
# spec file for package mlterm
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _configure ../configure
%if 0%{?sle_version} && 0%{?sle_version} < 150500
%global do_wayland 0
%global flavors with-gui=sdl2 with-gtk=3.0
%else
%global do_wayland 1
%global flavors with-gui=wayland with-gui=sdl2 with-gtk=3.0
%endif
Name:           mlterm
Version:        3.9.3
Release:        5.5
Summary:        Multilingual Terminal Emulator for X and Wayland
License:        BSD-3-Clause
Group:          System/X11/Terminals
URL:            https://mlterm.sourceforge.net/
Source0:        http://downloads.sourceforge.net/project/mlterm/01release/%{name}-%{version}/%{name}-%{version}.tar.gz
Source10:       %{name}.desktop
Patch0:         etc.patch
# https://github.com/arakiken/mlterm/commit/f971955cf54a721e6a53191c3b86fbdab4bfbfd5
Patch1:         mlterm-gcc14-f971955.patch
# https://github.com/arakiken/mlterm/commit/3d38b723e0e4a6dd434af2d49aca53890982a828
Patch2:         mlterm-gcc14-3d38b72.patch
# https://github.com/arakiken/mlterm/commit/08ba9859717ed27384675bd687a35f4504701f27
Patch3:         mlterm-gcc14-08ba985.patch
# https://github.com/arakiken/mlterm/commit/8aef4fae3add8e8acfafde831e0034f1b2879dea
Patch4:         mlterm-gcc14-8aef4fa.patch
# https://github.com/arakiken/mlterm/commit/20ab931d5055dc5835154a75ca672fade478549f
Patch5:         mlterm-gcc14-20ab931.patch
BuildRequires:  ccache
BuildRequires:  coreutils
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  scim-devel
BuildRequires:  uim-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(gail)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(ibus-1.0)
BuildRequires:  pkgconfig(libssh2)
BuildRequires:  pkgconfig(m17n-core)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(vte-2.91)
BuildRequires:  pkgconfig(wordcut)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xkbcommon)
Requires:       %{name}-common = %{version}-%{release}
Provides:       locale(xorg-x11:ja;ko;zh;ar;he)
%if 0%{?sle_version} && 0%{?sle_version} <= 150400
BuildRequires:  pkgconfig(fcitx)
%else
BuildRequires:  pkgconfig(Fcitx5Core)
BuildRequires:  pkgconfig(Fcitx5GClient)
%endif
%if %{do_wayland}
BuildRequires:  pkgconfig(wayland-client)
%endif

%description
Mlterm is a multilingual terminal emulator for the X Window System and Wayland.

Multilingual features:

supported charsets: US_ASCII, ISO8859[1-11], ISO8859[13-16], TCVN5712,
VISCII, KOI8_R, KOI8_U, JISX0201, JISX0208, JISX0212, JISX0213, GB2312,
GBK, KSC5601, UHC, CNS11643-N, Big5, UCS2(4)

supported encodings: ISO-8859-[1-11], ISO-8859- [13-16], TCVN5612,
VISCII, KOI8_R, KOI8_U, EUC-JP, EUC-JISX0213, ISO-2022-JP [1, 2, 3],
Shift_JIS, Shift_JISX0213, EUC-KR, UHC, JOHAB, ISO-2022-KR,
ISO-2022-CN, GB2312(EUC-CN), GBK, GB18030, EUC-TW, Big5, Hz, UTF-8

character composition: TIS620, TCVN5712, JISX0213, UNICODE

Multiple IMs are also supported and you can dynamically change various
IMs.

Other features:
* scroll by wheel mouse
* antialias font (requires Xft and Xrender extensions)
* proportional font
* transparent background
* background image (requires Imlib)
* multiple pty windows
* scrollbar plug-in API (unstable)

%package common
Summary:        Multilingual Terminal Emulator common files
Group:          System/Terminals
Conflicts:      %{name} < %{version}-%{release}
%if 0%{?suse_version} >= 1330
Requires:       group(tty)
%endif

%description common
Common files for Mlterm multilingual terminal emulator

%package sdl2
Summary:        Multilingual Terminal Emulator using SDL rendering
Group:          System/Terminals
Requires:       %{name}-common = %{version}-%{release}
Provides:       locale(ja;ko;zh;ar;he)

%description sdl2
Mlterm is a multilingual terminal emulator using SDL rendering

Multilingual features:

supported charsets: US_ASCII, ISO8859[1-11], ISO8859[13-16], TCVN5712,
VISCII, KOI8_R, KOI8_U, JISX0201, JISX0208, JISX0212, JISX0213, GB2312,
GBK, KSC5601, UHC, CNS11643-N, Big5, UCS2(4)

supported encodings: ISO-8859-[1-11], ISO-8859- [13-16], TCVN5612,
VISCII, KOI8_R, KOI8_U, EUC-JP, EUC-JISX0213, ISO-2022-JP [1, 2, 3],
Shift_JIS, Shift_JISX0213, EUC-KR, UHC, JOHAB, ISO-2022-KR,
ISO-2022-CN, GB2312(EUC-CN), GBK, GB18030, EUC-TW, Big5, Hz, UTF-8

character composition: TIS620, TCVN5712, JISX0213, UNICODE

Multiple IMs are also supported and you can dynamically change various
IMs.

Other features:
* proportional font
* background image (requires Imlib)
* multiple pty windows
* scrollbar plug-in API (unstable)

%package fcitx
Summary:        A fcitx plugin for mlterm
Group:          System/X11/Terminals
Provides:       locale(fcitx:ja;ko;ar;he)

%description fcitx
A plugin to use the fcitx input methods directly from mlterm.

%package ibus
Summary:        Ibus plugin for mlterm
Group:          System/X11/Terminals
Provides:       locale(scim:ja;ko;ar;he)

%description ibus
A plugin to use the ibus input methods directly from mlterm.

%package m17n
Summary:        A m17n plugin for mlterm
Group:          System/X11/Terminals
Provides:       locale(m17n:ja;ko;zh;ar;he)

%description m17n
A plugin to use the m17n input methods directly from mlterm.

%package scim
Summary:        SCIM plugin for mlterm
Group:          System/X11/Terminals
Provides:       locale(scim:ja;ko;ar;he)

%description scim
A plugin to use the SCIM input methods directly from mlterm.

%package uim
Summary:        An uim plugin for mlterm
Group:          System/X11/Terminals
Provides:       locale(uim:ja;ko;ar;he)

%description uim
A plugin to use the uim input methods directly from mlterm.

%prep
%autosetup -p1
rm -rf doc/{en,ja}/*win32

%build
export INSTALL_OPT='-m 755'

for i in %{flavors} ; do
mkdir $i
pushd $i
%configure \
  --disable-static \
  --libexecdir=%{_libdir}/mlterm \
  --sysconfdir=%{_sysconfdir}/X11 \
  --disable-utmp \
  --enable-anti-alias \
  --enable-fribidi \
  --enable-ssh2 \
  --enable-vt52 \
  --enable-ind \
  --enable-m17nlib \
  --enable-ibus \
  --enable-fcitx \
  --enable-scim \
  --enable-uim \
  --with-tools=mlclient,mlcc,mlfc,mlmenu,mlterm-zoom,mlimgloader,mlconfig \
  --with-scrollbars=sample,extra,pixmap_engine \
  --with-type-engines=xcore,cairo \
  --with-imagelib=gdk-pixbuf \
  --enable-optimize-redrawing \
  --$i
%make_build -O
popd
done

%install
for i in %{flavors} ; do
pushd $i
%make_install
popd
done
mkdir -p %{buildroot}%{_datadir}/pixmaps/
install -m 644 contrib/tool/mlterm-menu/menu %{buildroot}%{_sysconfdir}/X11/mlterm/
install -D -m644 "contrib/icon/%{name}-icon.svg" \
  "%{buildroot}%{_datadir}/pixmaps/%{name}.svg"
install -D -m644 "contrib/icon/%{name}-icon-trans.svg" \
  "%{buildroot}%{_datadir}/pixmaps/mlclient.svg"

%if %{do_wayland}
ln -s %{_mandir}/man1/mlterm.1 %{buildroot}%{_mandir}/man1/mlterm-wl.1
%endif
cp -a %{buildroot}%{_mandir}/man1/mlterm.1 %{buildroot}%{_mandir}/man1/mlterm-sdl2.1

mv %{buildroot}%{_libdir}/mlterm/mlterm/mlterm-zoom \
   %{buildroot}%{_bindir}/mlterm-zoom
find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file -i %{name} TerminalEmulator

%post -n %{name}-common -p /sbin/ldconfig
%postun -n %{name}-common -p /sbin/ldconfig

%files
%if %{do_wayland}
%attr(555,root,tty) %{_bindir}/mlterm-wl
%{_mandir}/man?/mlterm-wl.?.gz
%{_libdir}/mlterm/libim-kbd-wl.so
%{_libdir}/mlterm/libim-skk-wl.so
%endif
%attr(555,root,tty) %{_bindir}/mlterm
%{_bindir}/mlterm-zoom
%{_mandir}/man?/mlterm.?.gz
%{_datadir}/applications/%{name}.desktop
%dir %{_sysconfdir}/X11/mlterm/
%config %{_sysconfdir}/X11/mlterm/*
%{_libdir}/mlterm/libim-kbd.so
%{_libdir}/mlterm/libim-skk.so
%{_libdir}/mlterm/libathena.so
%{_libdir}/mlterm/libmotif.so
%{_libdir}/mlterm/libmozmodern.so
%{_libdir}/mlterm/libnext.so
%{_libdir}/mlterm/libsample.so
%{_libdir}/mlterm/libpixmap_engine.so
%{_libdir}/mlterm/libtype_cairo.so
%dir %{_libdir}/mlterm/mlterm
%{_libdir}/mlterm/mlterm/mlimgloader
%{_libdir}/mlterm/mlterm/mlconfig
%{_libdir}/mlterm/mlterm/mlmenu

%files common
%license LICENCE*
%doc README* doc/en doc/ja
%{_bindir}/mlclient
%{_bindir}/mlclientx
%{_bindir}/mlcc
%{_bindir}/mlfc
%{_libdir}/libpobl.*
%{_libdir}/libmlterm_coreotl.so
%{_libdir}/libmef.so*
%dir %{_libdir}/mef
%{_libdir}/mef/libmef_*
%dir %{_libdir}/mlterm/
%{_libdir}/mlterm/libctl_bidi.so
%{_libdir}/mlterm/libctl_iscii.so
%{_libdir}/mlterm/libind_assamese.so
%{_libdir}/mlterm/libind_bengali.so
%{_libdir}/mlterm/libind_gujarati.so
%{_libdir}/mlterm/libind_hindi.so
%{_libdir}/mlterm/libind_iitkeyb.so
%{_libdir}/mlterm/libind_inscript.so
%{_libdir}/mlterm/libind_kannada.so
%{_libdir}/mlterm/libind_malayalam.so
%{_libdir}/mlterm/libind_oriya.so
%{_libdir}/mlterm/libind_punjabi.so
%{_libdir}/mlterm/libind_telugu.so
%{_libdir}/mlterm/libotl.so
%{_libdir}/mlterm/libptyssh.so
%{_libdir}/mlterm/libzmodem.so
%{_mandir}/man?/ml[^t]*
%{_datadir}/pixmaps/*
%dir %{_datadir}/mlterm/
%dir %{_datadir}/mlterm/scrollbars/
%dir %{_datadir}/mlterm/scrollbars/sample3/
%{_datadir}/mlterm/scrollbars/sample3/*

%files sdl2
%attr(555,root,tty) %{_bindir}/mlterm-sdl2
%{_mandir}/man?/mlterm-sdl2.?.gz
%{_libdir}/mlterm/libim-kbd-sdl2.so
%{_libdir}/mlterm/libim-skk-sdl2.so

%files fcitx
%{_libdir}/mlterm/libim-fcitx*.so

%files ibus
%{_libdir}/mlterm/libim-ibus*.so

%files m17n
%{_libdir}/mlterm/libim-m17nlib*.so

%files scim
%{_libdir}/mlterm/libim-scim*.so

%files uim
%{_libdir}/mlterm/libim-uim*.so

%changelog
* Mon Aug 19 2024 pgajdos@suse.com
- fix build with gcc14 [bsc#1223886]
- added patches
  https://github.com/arakiken/mlterm/commit/08ba9859717ed27384675bd687a35f4504701f27
  + mlterm-gcc14-08ba985.patch
  https://github.com/arakiken/mlterm/commit/20ab931d5055dc5835154a75ca672fade478549f
  + mlterm-gcc14-20ab931.patch
  https://github.com/arakiken/mlterm/commit/3d38b723e0e4a6dd434af2d49aca53890982a828
  + mlterm-gcc14-3d38b72.patch
  https://github.com/arakiken/mlterm/commit/8aef4fae3add8e8acfafde831e0034f1b2879dea
  + mlterm-gcc14-8aef4fa.patch
  https://github.com/arakiken/mlterm/commit/f971955cf54a721e6a53191c3b86fbdab4bfbfd5
  + mlterm-gcc14-f971955.patch
- do not build with -fpermissive anymore
* Fri May  3 2024 Michal Suchanek <msuchanek@suse.com>
- Build with -fpermissive to make buildable with gcc14 (boo#1223886)
* Fri Apr 19 2024 pgajdos@suse.com
- drop wnn subpackage (https://build.opensuse.org/request/show/1166015)
  (FreeWnn seem to be no longer maintained)
* Thu Jul 13 2023 Michal Suchanek <msuchanek@suse.com>
- Disable wayland backend on 15.4 - fails to build.
* Fri Jun 23 2023 pgajdos@suse.com
- version update to 3.9.3
  * mlterm-wl supports xdg-decoration.
  * Add --disable-compact-truecolor option to ./configure script.
  * Add vte 0.68 API symbols to libvte compatible library.
  * Add libvterm 0.2 API symbols to libvterm compatible library.
  * Add --sdpr / simple_scrollbar_dpr option.
    (https://github.com/arakiken/mlterm/issues/64)
  * Set "COLORTERM=truecolor" environmental variable.
    (https://github.com/arakiken/mlterm/issues/36)
  * Update unicode property table (generated from UnicodeData.txt and
    EastAsianWidth.txt) to version 15.0.0.
  * Support mosh-1.4.0.
- deleted patches
  - CVE-2022-24130-c_sixel.c-Fix-segmentation-fault-when-the-repeat-cou.patch (upstreamed)
  - mlfc-Fix-crash-with-more-than-1024-font-faces-installed.patch (upstreamed)
  - mlterm-Fix-buffer-overflow-with-long-plugin-suffix.patch (upstreamed)
  - mlterm-SDL2-UI-also-needs-math-libs.patch (upstreamed)
  - mlterm-wayland-Detect-compiler-flags.patch (upstreamed)
* Fri Feb 24 2023 Michal Suchanek <msuchanek@suse.com>
- Build Wayland and SDL backends.
- Enable fcitx support
- Fix some crashes
  + CVE-2022-24130-c_sixel.c-Fix-segmentation-fault-when-the-repeat-cou.patch
  + mlterm-Fix-buffer-overflow-with-long-plugin-suffix.patch
  + mlfc-Fix-crash-with-more-than-1024-font-faces-installed.patch
- Fix some build problems
  + mlterm-SDL2-UI-also-needs-math-libs.patch
  + mlterm-wayland-Detect-compiler-flags.patch
* Mon Aug  8 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop canna support: canna has not been maintained for a long time
  and sec issues are not being addressed (bsc#1199280).
* Mon May 30 2022 pgajdos@suse.com
- version update to 3.9.2
  * Support Fcitx5.
  * Support GTK4 for mlconfig. (./configure --with-gtk=4.0)
  * Support CSI > Ps q (XTVERSION). (Response: DCS>|mlterm(3.9.2)ST)
  * Add "MOSH_UDP_PORT" environmental variable to specify UDP port or port-range
    to communicate with a mosh server.
  * Add INSERT_CLIPBOARD shortcut key.
    (https://github.com/arakiken/mlterm/issues/19)
  * Add --fk / format_other_keys option (equivalent to "formatOtherKeys" of xterm), and
    change the default format of the escape sequence with modifyOtherKeys from
    CSI Ps; Ps u to CSI 27; Ps; Ps ~.
  * Add --with-iconv, --disable-daemon, --disable-split and --disable-zmodem
    options to ./configure script.
  * Add vte 0.66 API symbols to libvte compatible library.
  * Show server list dialog at startup on Android.
  * It is deprecated to use "mlterm" as the value of termtype / -y option.
  * 'termcap' config file stops to accept multiple terminal types concated by '|'
    (e.g. xterm|xterm-256) as key.
  * Arabic ligatures (U+644-U+622, U+644-U+622, U+644-U+625, U+644-U+627) occupy
    two logical columns instead of one even if --dyncomb option isn't specified.
  * KBD_INPUT_NUM and MOUSE_INPUT_NUM environmental variables (for mlterm-fb)
    accept multiple device numbers by "<num>,<num>".
  * Show "Config: key=value" only if shortcut keys whose format is
    "proto:(echo)key=value" is pressed.
  * Merge patches:
    https://github.com/arakiken/mlterm/pull/5.
    https://github.com/arakiken/mlterm/pull/9.
    https://github.com/arakiken/mlterm/pull/12.
    https://github.com/arakiken/mlterm/pull/22.
  * Bug fixes:
    Fix https://github.com/arakiken/mlterm/issues/15.
    Fix https://github.com/arakiken/mlterm/issues/18.
    Fix https://github.com/arakiken/mlterm/issues/24.
    Fix https://github.com/arakiken/mlterm/issues/28.
    Fix failure of restarting mlterm on Android. (Enbugged at 3.9.1)
    Fix segfault if mlterm screen with -t option goes outside of the display.
    Fix emoji glyphs becoming too large with cairo.
    Fix corrupt value of "word_separator" option which mlconfig outputs.
    Fix incompatibility with xterm in pressing Shift + a-z keys etc if modifyOtherKeys is 1.
    (https://github.com/arakiken/mlterm/issues/21)
    Fix segfault in opening a new roxterm tab with libvte compatible library on wayland.
- modified patches
  %% etc.patch (refreshed)
* Tue Mar 30 2021 pgajdos@suse.com
- version update to 3.9.1
  * Support copy mode which starts by Control+Shift+Return.
  * Support OSC 1337;Setmark ST.
  * Support CSI 3 J (ED) which clears backlog.
  * Support gradle to build mlterm for Android. (See doc/en/README.android)
  * Add --enable-utmp-suid option to ./configure script.
    (The default value is disabled.)
  * Add --with-utmp option which specifies the way of accessing to utmp database
    to ./configure script.
  * Add SCROLL_UP_TO_MARK, SCROLL_DOWN_TO_MARK and SET_MARK shortcut keys.
  * Add resize_mode / --rz option, and drop scroll_on_resize / --sr option.
    (If you want to revert to the old behavior, specify --rz=none option.)
  * Add emoji_file_format / --emojifmt option.
  * Add libvterm 0.1 API symbols to libvterm compatible library.
  * Add vte 0.62 API symbols to libvte compatible library.
  * Drop SCROLL_DOWN and PAGE_DOWN shortcut keys.
  * Drop use_extended_scroll_shortcut option and SCROLL_UP shortcut key is enabled
    by default. (If you want to disable it, add UNUSED=SCROLL_UP to ~/.mlterm/key.)
  * Update unicode property table (generated from UnicodeData.txt and
    EastAsianWidth.txt) to version 13.0.0.
  * letter_space / --csp option accepts negative value.
  * libvte compatible library supports XInput2.
  * Bug fixes:
    Fix a bug which caused a 'mlimgloader' process not to exit after loading a wall picture.
    (Enbugged at 3.8.8)
    Fix a bug which disabled keyboard and mouse on Haiku R1/beta2.
    Mlconfig starts correctly by Ctrl + RightClick on cygwin 3.1.4.
    Fix https://sourceforge.net/p/mlterm/mailman/message/37033060/
    Fix segfault of mlcc in exiting after changing configurations.
    Fix segfault in double click at RTL characters. (Enbugged at 3.6.2)
    Fix corruption of data transferred by "OSC 5379; scp ... ST".
    Fix https://github.com/arakiken/mlterm/issues/4.
    Fix http://twitter.com/oshimyja/status/1320251099211649024.
* Wed Sep  2 2020 pgajdos@suse.com
- version update to 3.9.0
  * Support CSI>4;1m.
  * Support uniscribe for libotl on win32.
  * Support SCP by Shift+DnD on HaikuOS.
  * Support xdg-shell on wayland.
  * Support DEC Technical character set.
  * Support input of unicode characters on mlterm-fb.
  * Support ormode of Sixel Graphics.
  * Update unicode property table (generated from UnicodeData.txt and
    EastAsianWidth.txt) to version 12.1.0.
  * Mlconfig configures files in ~/.mlterm directly if it starts without options
    or with --file option.
  * Change DA1 response.
    \x1b[?63;1;2;3;4;7;29c -> \x1b[?63;1;2;3;4;6;7;15;18;22;29c
  * geometry / -g option works on HaikuOS.
  * Add vte 0.60 API symbols to libvte compatible library.
  * Merge patches:
    https://sourceforge.net/p/mlterm/bugs/78/
    https://sourceforge.net/p/mlterm/patches/25/attachment/typos.diff
  * Bug fixes:
    Fix a bug which disabled to change the value of "logsize" option from "0" to "unlimited".
    Fix segfault when "snapshot" command of OSC 5379 is executed.
    Fix mouse tracking position if "use_ot_layout = true".
    Fix segfault when mlterm-sdl2 starts with -im=uim option.
    Fix a bug which makes mlterm-sdl2 on win32 stop starting mlconfig.
    Fix compiling error on HaikuOS + gcc-x86.
    Fix http://twitter.com/hamano/status/1177087752208183296
    Fix a bug which disabled clipping of DECDHL in cairo. (Enbugged at 3.8.6)
- deleted patches
  - mlterm-cast.patch (upstreamed)
* Thu Dec 19 2019 pgajdos@suse.com
- version update to 3.8.9
  * Support zmodem. (See doc/en/README.tarnsfer)
  * Add "send_file" and "zmodem_start" to OSC 5379.
  * Add receive_directory / --recvdir option.
  * Support xdg-shell-v6 (unstable) on wayland.
  * Support copy&paste via X11 primary selection on wayland.
  * Hide the mouse cursor in inputting keys by default on xlib and win32.
  * ~/.mlterm/font accepts UTF-8 on windows.
  * Change the default value of "font_size_range" option from 1-100 to 1-10000.
  * Clear a window and scroll out all lines on resizing only if
    the value of --sr / "scroll_on_resizing" option is true.
  * Set _NET_WM_PID property.
  * Revive -N/"app_name" option which sets WM_CLASS property.
    (WM_CLASS was disabled at 3.8.6)
  * Add a percent or number argument without '+' and '-' to "vresize_screen" and
    "hresize_screen" of OSC 5379.
  * Add "RESET" (which resets the parser of mlterm) as a shortcut key.
  * Add vte 0.58 API symbols to libvte compatible library.
  * Merge patches:
    https://bitbucket.org/arakiken/mlterm/pull-requests/5/fix-for-wscons-framebuffer/diff
    https://sourceforge.net/p/mlterm/patches/24/
  * Bug fixes:
    Fix memory leaks of libptymosh.so
    Fix https://sourceforge.net/p/mlterm/mailman/message/36633222/ (Enbugged at 3.8.8)
    Fix segfault of mlterm for java by race condition.
    Fix unexpected invalidation of --mdi=false option. (Enbugged at 3.8.8)
    Fix uninitialized memory access of mlimgloader.exe for win32.
    Fix broken images of some sixel graphics. (Enbugged at 3.8.5)
  * Support Haiku OS. (Experimental)
    (Execute ./configure with --with-gui=beos option.) (See doc/en/README.beos)
  * Support "[font family]:style=..." format in aafont or font-fb config file.
  * Support mosh. (Experimental) (See doc/en/README.mosh)
    (Don't distribute libptymosh in binary format.)
  * Clear a window and scroll out all lines if the size of a window decreases
    and some characters in it disappear.
  * Support "%%s" (replaced by selected strings) in "exesel:..." in ~/.mlterm/key.
  * Add local_echo_wait / --lew option.
  * Remove libind_tamil.so because it is very buggy.
  * Change the default shortcut key of INSERT_SELECTION from Shift+Insert to
    Command+v on MacOSX and iOS.
  * Skip \r in configuration files.
  * Start scp by Shift+Drag&Drop on not only xlib and win32 but also wayland, sdl2
    and cocoa. (Command+Drag&Drop on cocoa.)
  * Change the default value of "font_size_range" option from 6-30 to 1-100.
  * Add vte 0.56.0 API symbols to libvte compatible library.
  * Bug fixes:
    Fix https://sourceforge.net/p/mlterm/mailman/message/36472061/
    Fix https://sourceforge.net/p/mlterm/mailman/message/36513313/
    Fix https://sourceforge.net/p/mlterm/bugs/79/
    Fix segfault in processing illegal sixel sequence.
    Fix invalidation of DECDWL on cairo. (Enbugged at 3.8.6)
    Fix handling ISCII fonts on cairo and xft. (Improve showing bengali characters.)
    Fix screen corruption (http://twitter.com/Cj_bc_sd/status/1088111309223161857)
    on MacOSX 10.14. (Thanks to @Cj_bc_sd)
    Fix segfault in showing an input method window. (Thanks to @isaki68k)
- modified patches
  %% etc.patch (refreshed)
  %% mlterm-cast.patch (refreshed)
* Fri Dec 28 2018 Petr Gajdos <pgajdos@suse.com>
- updated to 3.8.7
  * Support sixel graphics extension and option1 of
    https://github.com/kmiya-culti/RLogin/issues/22#issue-341758598
  * Support Cygwin/x86_64.
  * Support PS2 mouse and PC98 bus mouse on FreeBSD 4.x or before.
  * Support iOS/Cocoa Touch. (see doc/en/README.cocoatouch)
  * Support scrolling by flick on Android and iOS.
  * Update unicode property table (generated from UnicodeData.txt and
    EastAsianWidth.txt) to version 11.0.0.
  * Add "autoscroll" to OSC 5379.
  * Long press at the lower right corner instead of the entire screen shows
    context menu.
  * Change the maximum number of sixel graphics palette colors from 256 to 1024.
  * Bug fixes:
    Fix segfault of mlconfig when GTK_IM_MODULE=uim.
    Fix wrong XSizeHints which causes unexpected resizing.
- refreshed
  %% etc.patch
* Fri Aug 24 2018 pgajdos@suse.com
- updated to 3.8.6
  * Support preserveAspectRatio option of OSC 1337.
  * Support DECRQCRA, CSI 15 t, CSI 16 t, CSI 19 t and OSC 5;Ps;? ST.
  * Support framebuffer on FreeBSD(98).
  * Add vte 0.52.0 API symbols to libvte compatible library.
  * Add --rv / "rv_color" option.
  * Add servman.exe which manages the list of servers on win32.
  * Add "PrivKey" entry to the ssh connection dialog on win32 and Android.
  * Add "SCP" entry to the context menu on Android.
  * Drop --servlist / "server_list" option.
  * Improve performance of redrawing screen when type_engine=cairo.
  * Show box style cursor when the cursor is on a picture or an emoji.
  * Modify DECRC to save/restore last-column flag used to control wrapping behavior
    rather than manipulating DECAWM (See https://github.com/mattiase/wraptest and
    https://invisible-island.net/xterm/xterm.log.html#xterm_328)
  * Change the default value of ssh_private(public)_key option from
    /sdcard/.ssh/id_rsa(.pub) to /sdcard/.mlterm/id_rsa(.pub) on Android.
  * Bug fixes:
    Fix compiling error if ./configure is executed with --with-gui=fb,xlib option.
    Fix disappearing title bar on 'lxde' window manager.
    Fix a bug which disabled to replace system palettes by colors of a wall picture
    (if "use_ansi_colors" option is disabled and visual depth is 4) since 3.8.4.
    Fix the response strings of OSC 20 and OSC 21.
    Use the background color specified by SGR instead of the default one to draw
    pictures and emojis.
  * Support libvterm (https://launchpad.net/libvterm) compatible library partially.
  * Support DRCS-Sixel.
    (See drcssixel/DRCS-SIXEL-v2 and https://qiita.com/arakiken/items/626b02cd857d20c12fbc)
  * Support SDL2.
    (Build mlterm with --with-gui=sdl2 option.) (see doc/en/README.sdl2)
  * Support ligature of "Fira Code" font in -otl option.
  * Add --halfwidth / "unicode_half_width_areas" option.
  * Add --emoji / "emoji_path" option which makes mlterm to use a specified emoji font
    (NotoColorEmoji.ttf etc) instead of image files in ~/.mlterm/emoji.
  * Add vte 0.50.0 API symbols to libvte compatible library.
  * Treat not only U+1F1000-1F6FF but also U+1F900-1F9FF characters as emoji.
  * Drop "show_picture" and "add_frame" from OSC 5379.
  * Bug fixes:
    Fix corrupt screen in showing inline pictures if "use_ot_layout" option is true.
- mlterm-portability.patch renamed to mlterm-cast.patch
* Fri Feb 16 2018 crrodriguez@opensuse.org
- Add explicit buildrequires on x11 and fontconfig, do not
  count on them being pulled by other packages.
* Mon Dec 18 2017 pgajdos@suse.com
- updated to 3.8.2:
  * Support DECSLPP, DECSCPP, DECBBSM, DECRQTSR, DECCTR, DECRQPSR, DECSNLS, DECSTGLT, DECRSPS,
    DECSR, CSI 7 t, CSI 9;1 t, CSI ? Pm s, CSI ? Pm r, CSI 34 [hl], CSI 53 m and CSI 55 m.
  * Support DECSASD, DECSSDT unless vertical mode is enabled.
  * Support 90-degree rotation of alphabet glyphs in vertical mode (cjk alone) on framebuffer,
    wayland and android if freetype is enabled.
  * Support sticky shift key of skk im module, and change the format of skk option from
    "skk:[dictionary]" to "skk:dict=[dictionary],sskey=[sticky shift key]".
  * Add "use_vertical_cursor" and "click_interval" to OSC 5379, 5380 and 5381.
  * Add "ot_features" and "ot_script" to OSC 5380 and 5381.
  * Add "Features" and "Script" buttons to "Encoding" tab of mlconfig.
  * Add "Underline pos (pixels)" and "Baseline pos (pixel)" to "Font" tab of mlconfig.
  * Add "Double click interval (msec)", "Send keys to all windows" and
    "Trim trailing CR/LF in pasting" to "Others" tab of mlconfig.
  * Add doc/en/ControlSequences which lists escape/control sequences which mlterm supports.
  * Change the default value of "use_vertical_cursor" option from false to true.
  * Drop "CSI ? 9500 [hl]".
  * Improve processing sixel graphics on pseudo color framebuffer.
  * Merge patches:
    https://sf.net/p/mlterm/patches/_discuss/thread/f5dc445d/0fc3/attachment/fix_spelling.diff
  * Add "trim_trailing_newline_in_pasting" / --trim option which removes trailing
    newline characters in pasting text.
  * Add "broadcast" / --bc option which broadcasts input or pasted characters to
    all ptys whose value of "ignore_broadcasted_chars" option is false.
  * Add "ignore_broadcasted_chars" / --ibc option.
  * Add "Next pty", "Previous pty" and "Close screen" to context menu on Android.
  * Add "next_pty", "prev_pty" and "close_screen" to OSC 5379.
  * Add "fontconfig" to OSC 5380.
  * Support libssh2 on MacOSX/Cocoa.
  * Support ModifyCursorKeys and ModifyFunctionKeys of xterm.
  * Support OSC 0 and OSC 1 on MacOSX/Cocoa.
  * Support _NET_WM_NAME and _NET_ICON_NAME properties on xlib.
  * Support "CSI > Ps t" and "CSI > Ps T".
  * Support "CSI 20 h" and "CSI 20 l" (LNM).
  * Support right click menu on libvte compatible library on wayland.
  * Support fcitx input method module on wayland.
  * Support italic on MacOSX/Cocoa.
  * Remove --hscr / "screen_height_ratio" option.
  * Change the default sequences of Modifier+Function and Modifier+Cursor keys
    from xterm's old/obsolete ones to modern ones.
    (e.g. Shift+F1 outputs "\e[1;2P" instead of "\eO2P" by default.)
  * Merge patches:
    https://bitbucket.org/arakiken/mlterm/pull-requests/3/update-a-left-old-code-about-the
  * Bug fixes
- see doc/ReleaseNote for details
* Tue Jul 18 2017 tchvatal@suse.com
- Version update to 3.8.2 release:
  * Support for wayland
  * Support page of VT400 or later. (NP, PP, PPA, PPR, PPB, DECCRA and DECLRP)
  * Support DECRQDE, DECSCUSR(Ps = 3,4,5,6), DECATC, DECRQM, DECRQMH, DECSCA,
    DECERA, DECSEL and DECSED.
  * Support SGR of DECRQSS.
  * Bunch of bugfixes
- Add all the named dependencies to the package to make sure all the
  features are properly enabled, configure script does not fail on
  dependencies not found
- Remove libotf as now rendering is done via harfbuzz
- Disable fctix input method as it fails to compile upstream
- Install svg icons from the archive rather than our distributed png
- Add portability patch mlterm-portability.patch to make rpmlint happy
* Mon Nov 21 2016 pgajdos@suse.com
- updated to 3.7.2
  * Add mlterm-con which is a console version of mlterm (like
    GNU Screen) and which works on various terminal emulators.
    (see doc/en/README.console)
  * Add "console_encoding" / --ckm option which specifies
    a character encoding of the console where mlterm-con works.
  * Add "default_cell_size" / --csz option for mlterm-con.
  * Add "console_sixel_colors" / --csc option for mlterm-con.
  * Add "primary_da" / --da1 and "secondary_da" / --da2 options.
  * Support DECRQSS partially.
  * Support wheel mouse on MacOSX/Cocoa. (Thanks to @nyarla)
    (Merge a patch at http://the.nyarla.net/entry/2016/06/03/195013)
  * Bug fixes:
    Fix misalignment of the position of characters in drawing
    them with the use of complementary loaded fonts on cairo.
- removed mlterm-noreturn.patch (upstreamed)
* Wed Mar 23 2016 idonmez@suse.com
- Update to version 3.7.0
  * Support OSC 1337. (See http://www.iterm2.com/images.html)
  * Add 'mlfc' tool which automatically generates ~/.mlterm/aafont and ~/.mlterm/font-fb.
  * Change the format of ~/.mlterm/*font is changed as follows.
    [Charset] = [Font name];[Size],[Font name];[Size],[Font name];...
  - > [Charset] = [Font name]
  * Drop XT_CBLINK (CSI?12h/CSI?12l) support.
  * Simplify font configuration of OSC 5379. ('mlcc font USASCII <Font name>' is available.)
  * "CSI 38;2;r;g;b m" and "CSI 48;2;r;g;b m" shows high colors instead of
    approximate vt 256 colors. "vt_color_mode" / --vtcolor(=256/high/true) option
    changes the behavior.
- Add mlterm-noreturn.patch to fix signature of non-returning function.
* Wed Dec 16 2015 pgajdos@suse.com
- updated to 3.6.1:
  * Support DECDHL and DECDWL.
  * Add 'autohide' value to 'scrollbar_mode' option
  * Disable conversion from Unicode to ISCII if use_ctl = false.
  * Support ssh2 connection on framebuffer.
  * Set XID of text screen instead of top window as the value of
    WINDOWID environmental variable.
  * Add "geometry" to OSC 5379.
  * Add "mlconfig" to OSC 5379.
  * Add "Columns" and "Rows" to "Others" tab of mlconfig.
  etc., see en/ReleaseNote for details
* Mon Sep  7 2015 tiwai@suse.de
- Run spec-cleaner
- Disable scim and uim plugins for SLE12 and openSUSE Leap builds
* Tue May 12 2015 pgajdos@suse.com
- updated to 3.4.5:
  * "Alt" which equals to "Mod" is available in ~/.mlterm/key.
  * mlclient doesn't depend on kiklib.
  * ~/.config/mlterm/challenge is supported.
  * 0x0 - 0x7f characters are treated as US_ASCII instead of
    ISO10646_UCS4_1.
  * Extra margin area at the right and bottom edges is cleared
    in maximizing a window.
  * The default value of "use_clipboard" option is
    changed from "false" to "true".
  * etc, see ChangeLog
* Tue Nov 18 2014 pgajdos@suse.com
- updated to 3.4.0:
  * Support DEC Locator mode (which is necessary for Xsixel
    (http://github.com/saitoha/xserver-SIXEL)).
  * Support CSI > 2 p (for SDL-sixel and Xsixel) which always hides mouse pointer
    even if it moves. (Not compatible with xterm though.)
  * Add --point/use_point_size option.
  * Support software keyboard on rotated display.
  * Support HLS in sixel sequence.
  * Embed sixel processing to mlterm which is built without --with-imagelib option
    instead of using 'mlimgloader' to improve performance.
  * Support rectangle selection by pressing alt key while selecting.
  * Support DECDMAC/DECINVM.
  * Start scp by drag&drop a file with shift key to the screen on ssh connection.
  * Add --seqfmt/vt_seq_format option.
  * Read /dev/kbd on NetBSD/x68k framebuffer.
  * Add "Auto detect" entry to "Encoding" tab of mlconfig.
  * Add "Local echo" checkbox to "Others" tab in mlconfig.
  * Enable image processing on background terminals.
  * Improve the performance of processing images on 8 or less bpp framebuffer.
  * Support SGR 5, 9, 21, 25 and 29.
  * Support DECFRA, SL and SR.
  * Starting mlterm with -j option executes mlclient if daemon process has already
    started.
  * Change the maximum number of "U+XXXX-XXXX" in ~/.mlterm/(t,v,)(aa)font
    from 7 to 511.
  * Add "unlimted" to "Backlog size" entry in mlconfig.
    Add "UNICODE (ARABIC)" and "UNICODE (EMOJI)" to "Font name" entry.
  * Add --it/it_color, --bl/bl_color and --co/co_color options.
  * Add --itfont/use_italic_font option.
  * Add --bisep/bidi_separators option.
  * Add --fullwidth/unicode_full_width_areas option.
  * Add --working-directory/working_directory option.
  * Add --deffont option.
  * Disable "_HALFWIDTH" suffix in ~/.mlterm/(t,v)(aa)font files.
  * Drop --ucsprop/use_unicode_property option.
  * Bug fixes: see ReleaseNote for details
* Mon Jun 23 2014 pgajdos@suse.com
- updated to 3.3.6:
  * Support fcitx. (Experimental)
  * Remove the original "simple" scrollbar and link "sample" scrollbar statically
    to mlterm as "simple" one. Rename "sample2" scrollbar to "sample".
  * Bug fixes:
    Fix partially corrupt screen in drawing animation gif.
    Fix https://twitter.com/yoshikaw/status/462125454107738112
    Fix corrupt screen in drawing large images.
    Fix https://twitter.com/kefir_/status/467340224628924416
    Fix the corrupt scrolling in vertical mode.
  * Support Animation GIF on "show_picture" of OSC 5379.
    (It works with https://bitbucket.org/arakiken/w3m/get/remoteimg.tar.gz)
  * Add "add_frame" to OSC 5379.
  * Bug fixes:
    Fix compiler error on NetBSD/OpenBSD framebuffer. (enbugged at 3.3.4)
    Fix the bug which sometimes disabled to show large sixel graphics sequence.
    (enbugged at 3.3.4)
    Output ^? instead of ^H on TERM=xterm by default in pressing backspace key.
    Fix the bug which sometimes left X11 events untouched for a while.
    Fix the bug of closing the input method window unexpectedly in pressing it.
    ":Percentage" after font names in ~/.mlterm/aafont works on cairo.
- refreshed etc.patch; kterm rule is part of upstream termcap yet, so it
  was dropped from the patch
* Sun Jun  1 2014 jengelh@inai.de
- Drop unused build-time requirements on libotf, libtiff, libgif
* Mon Mar 31 2014 pgajdos@suse.com
- updated to 3.3.4:
  * Support not only sixel graphics but also other major image formats on Android.
  * Support ReGIS partially. (depends on SDL(SDL2), SDL_ttf(SDL2_ttf) and fontconfig)
  * Output strerror(errno) on error.
  * Support "key=value #comment" style in the same line in ~/.mlterm/main.
  * Draw all ambiguous width characters one by one to fit the column width unless
  - V option is specified.
  * Merge patches:
    https://gist.github.com/tsutsui/9285759.
  * bugfixes, see doc/en/ReleaseNote for details
* Wed Nov 27 2013 pgajdos@suse.com
- updated to 3.3.1:
  * Add "use_auto_detect" and "auto_detect_encodings" options.
    (auto_detect_encodings=utf8,eucjp,sjis and use_auto_detect=true enable
    auto detection of utf8, eucjp and sjis.)
  * Support ESC $ on non-ISO2022 encodings such as UTF-8.
  * Reset pending DCS sequence by pressing ESC key.
  * Support iBus 1.5.
  * Enable to specify the conversion engine name of iBus. (e.g. --im ibus:anthy)
  * Desynchronize ESC [ 5379 ; show_picture BEL on cygwin/win32gdi or mingw.
  * "unlimited" value is available for "logsize" option.
  * Bug fixes:
    Fix the bug of convertion to sjis.
    Fix the bug which disabled threading scp.
    Fix https://bugzilla.novell.com/show_bug.cgi?id=849342
  etc., see doc/en/ReleaseNote
- removed fix-biwidth-font-search.diff (upstreamed)
* Wed Nov  6 2013 tiwai@suse.de
- mlterm-fix-biwidth-font-search.diff:
  Fix missing biwidth characeters as default with X11 core fonts
  (bnc#849342)
- Update font and aafont config files to use FreeMono and IPAGothic
  in etc.patch (bnc#849342)
* Mon Sep  9 2013 pgajdos@suse.com
- updated to 3.2.2:
  * Support SSH agent authentication and forwarding.
  * Support X11 forwarding (no xauth) on win32/libssh2 and java.
  * Add "X11 forwarding" checkbox to the connection dialog on win32.
  * Change "skip_dialog" option to "show_dialog" and reverse the default behavior.
  * Open a pty channel on the same ssh session as the active screen when OPEN_PTY
    or OPEN_SCREEN shortcut key is pressed.
  * Support software keyboard on framebuffer.
    (Double-click Button1 at the right bottom corner of the screen to show it.)
  * Support USB keyboard with iBus on NetBSD/OpenBSD framebuffer.
  * Support CSI ? 69 h, CSI ? 69 l (DECLRMM) and CSI pl;pr s (DECSLRM).
  * Support CSI 3 m and CSI 23 m which set/unset italic attribute.
  * Prefer JISX0208 to JISX0213 all the time in converting Unicode to other cs.
  * If DEFAULT=-foo-bar-medium-r-*--%%d-*- is specified in ~/.mlterm/font,
  - foo-bar-bold-r-*--%%d-*-, -foo-bar-medium-i-*--%%d-*- or -foo-bar-bold-i-*--%%d-*-
    are automatically searched for a bold, italic or bold italic font.
  * Support 1 bpp framebuffer.
  * Support sixel graphics and wall pictures on 1 and 8 bpp framebuffer.
  * etc. see doc/en/ReleaseNote
* Tue Mar 26 2013 pgajdos@suse.com
- updated to 3.1.9:
  * Remove --enable-sixel option from configure, and add --disable-image option.
    That is, support sixel graphics by default unless configure with
  - -disable-image option. (w3m-remoteimg (https://bitbucket.org/arakiken/w3m/downloads)
    which doesn't depend on sixel graphics but on OSC 5379 show_picture also works
    on mlterm by default.)
  * Separate SSH client functions to a dynamically loaded module (libptyssh)
    in platforms except win32.
  * Treat key strings of "main" configuration file case-insensitively.
    (Both encoding=utf8 and ENCODING=utf8 are available.)
  * Assign -M and -P options as the short options of --im and --clip.
  * Add "allow_change_shortcut" (--shortcut) option which enables "set_shortcut"
    command of configuration protocol.
  * Bug fixes:
    Fix the conflict of DCS(0x90) and the first byte of SJIS, GBK and so on.
    Fix the bug which disabled input and output of pty when configuration program
    such as mlconfig is started.
    Encode input character masked with 0x80 to the character encoding of pty
    if the value of mod_meta_mode option is 8bit. (Thanks to Vladimir Elisseev)
    Fix the bug which disabled Alt+symbol and Control+@ in win32.
    Fix the bug which disabled some shortcut key settings.
  etc. see doc/en/ReleaseNote
* Tue Dec 18 2012 pgajdos@suse.com
- updated to 3.1.6:
  * Sixel graphic pictures are divided to the screen cells.
  * Cursor blinking is enabled not only by VTE_CURSOR_BLINK_ON
    but also VTE_CURSOR_BLINK_SYSTEM.
  * Color names defined in ~/.mlterm/color are not available for
  - fg, -bg, -sbfg and -sbbg options.
  * Unicode line drawing characters like U+2500 etc are converted to
    dec special ones if -Y option is specified.
  * Gzipped pcf fonts are available.
  * etc/font-fb: unifont.pcf is added.
  * etc. see doc/ReleaseNote
- removed patches:
  * cast-from-pointer-to-integer-of-different-size.patch
  * mlconfig_fixdups.diff
  * mlterm-configure.patch
* Thu Jun  7 2012 swyear@gmail.com
- remove "Provides: locale(scim:zh)" from sub-package mlterm-scim
* Tue Nov  1 2011 pgajdos@suse.com
- updated to version 3.0.8:
  * Change default value of "use_ind" option from true to false.
  * Merge SF Patches: #3412453 (Thanks to Ahmed El-Mahmoudy)
  * Fix wrong origin setting by CSI ? 6 l. (Thanks to Konosuke
    Watanabe san)
  * Fix a problem which causes segmentation fault if both -J
    and -bi options are specified.
  * etc, see en/ReleaseNote
* Tue May 31 2011 pgajdos@novell.com
- updated to version 3.0.3:
  * palette settings are reflected in vte_terminal_set_colors()
  * "--initstr" option is prohibited in "mlclient" configuration
    protocol.
  * x_color_cache_256_t.is_loaded is cleared
    in unloading 256 colors in x_color_cache_unload() instead of
    x_color_cache_t.is_loaded.
  * etc. see ChangeLog
  * removed some patches with hope that they are not needed:
  - kiklib-configure.patch
  - po.patch
  - gettext-version.patch
  - norootforbuild.patch
  - pkconfig.patch
  - fribidi-link-fix.diff
* Thu Nov 11 2010 pgajdos@suse.cz
- updated to version 3.0.1:
  * fixed infinite loop. when a sequence-like input was actually
    so looooong, mlterm should assume it was just not properly
    terminated (Thanks to shinichiro.h).
  * should not loop forever when window was too narrow.
  * Check if button is pressed before win->button_motion is called.
  * Changed font and color configuration protocol numbers(not
    compatible with cvs-2009/10/20 or before.)
  * Modifier keys with Del/Home/End are distinguished.
    The keypad middle key (XK_Begin, XK_KP_Begin) is mapped to
    ^[[E, ^[[1;5E etc.
  * The default value of button3_behavior option is changed
    from "menu1" to "xterm".
  * "ESC[9Nm" and "ESC[10Nm" sequences are supported.
- removed unneeded
  * scim.patch
  * cross-compile-not-needed.patch
  * uim-build-fix.diff
* Thu Sep  9 2010 aj@suse.de
- BuildRequire utempter-devel
* Fri Jan  8 2010 ro@suse.de
- drop imlib-devel from buildrequires (unused)
* Fri Dec 11 2009 tiwai@suse.de
- removed unused mlterm-lib64.patch
* Mon Nov 30 2009 crrodriguez@opensuse.org
- fix build, patches with fuzz=0
* Wed Jul  8 2009 tiwai@suse.de
- updated to version 2.9.4:
  minor cleanups after the last CVS
* Tue Jul  7 2009 tiwai@suse.de
- fix build of im-uim plugin on FACTORY (missing BUFSIZ definition)
- fix the link order to resolve symbols correctly
* Thu Aug 28 2008 kukuk@suse.de
- Don't link against old imlib
* Fri Mar 14 2008 schwab@suse.de
- Run autoreconf only once and make sure no obsolete macros are present.
- Always use the included libtool.
* Mon Nov 12 2007 mfabian@suse.de
- update to 2.9.3.20071112 (= 2.9.4 pre):
  • mlterm/x_screen.c: added config key string "title" to allow
    change pty title by "mlcc title foobar".
  • mlter/ml_term.h: updated for ml_vt100_parser_set_logging_vt_seq.
  • xwindow/x_dnd.h: handle zero-length property properly.
  • xwindow/x_screen.c: selection can be expanded on middle-click.
    (Thanks to ssakane)
- remove bugzilla-238194-array-subscript-out-of-bounds.patch
  (included upstream).
- fix the build with gcc 4.3.
* Wed Jan 24 2007 mfabian@suse.de
- update to 2.9.3.20070123 (= 2.9.4 pre).
- fix Bugzilla #238194.
* Fri Sep  8 2006 mfabian@suse.de
- update to 2.9.3 (various bugfixes).
- remove mlterm-lib64.patch (included upstream).
- remove buggy_wm.diff (now included).
- remove bugzilla-105320-use-utempter.patch (included upstream).
- remove fix-implicit-declarations_2.patch (included upstream).
* Fri Aug 11 2006 mfabian@suse.de
- fix build (mkinstalldirs problem).
- move binaries from /usr/X11R6/bin to /usr/bin (because of X11R7).
* Mon Jun 19 2006 schwab@suse.de
- Don't use automake macros without using automake.
* Wed Mar  8 2006 kkaempf@suse.de
- fix locale(...) provide.
* Wed Mar  1 2006 mfabian@suse.de
- add "Provides: locale(xorg-x11:ja,ko,zh,ar,he)" and
  similar provides to the sub-packages.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 29 2005 sbrabec@suse.cz
- Do not install terminfo entry already present in ncurses.
  Cleans rpm -V output.
* Sun Oct  2 2005 stbinner@suse.de
- fix capitalization of .desktop GenericName entry
* Thu Sep 22 2005 mfabian@suse.de
- use better patch to fix the implicit declarations by
  MINAMI Hirokazu <minami@mistfall.net>.
* Thu Sep 22 2005 mfabian@suse.de
- fix implicit declarations.
* Mon Aug 22 2005 mfabian@suse.de
- Bugzilla #105320: use libutempter again.
* Fri Aug 19 2005 tiwai@suse.de
- added icon file and fixed desktop file (#105842)
* Tue Aug  2 2005 ro@suse.de
- use gtk2-devel-packages in nfb
* Mon Jun  6 2005 uli@suse.de
- fixed to build with SCIM 1.3
* Wed May 18 2005 ro@suse.de
- fix build with current pkgconfig
* Wed May  4 2005 mfabian@suse.de
- Bugzilla #81227: split input method plugins into sub-packages
  (mlterm-scim, mlterm-uim, mlterm-m17n) so that mlterm itself
  doesn't require scim, uim, or m17n.
* Fri Apr  1 2005 schwab@suse.de
- Fix broken configure script.
* Thu Mar 17 2005 mfabian@suse.de
- add patch for transparency on buggy window managers
- add default keybinding KP_Begin="\e[E" (requested by
  the mined author, Thomas Wolff <mined@towo.net> to make the
  '5' key usable in mined.
* Mon Mar  7 2005 mfabian@suse.de
- update to 2.9.2:
  + [SECURITY] Fixed possible integer overflow.
- enable scim support
* Tue Feb 15 2005 mfabian@suse.de
- update to 2.9.1.20050215
* Wed Jan 19 2005 mfabian@suse.de
- update to 2.9.1.20050119 (now includes fix by
  Seiichi SATO <ssato@sh.rim.or.jp> to make IM plugin work with
  libltdl even when the plugin directory contains .a and .la files.
* Fri Jan 14 2005 mfabian@suse.de
- update to 2.9.1.20050114
- add "Shift+space=IM_HOTKEY" to /etc/X11/mlterm/key.
- Bugzilla #42964: add mlterm terminfo entry and make TERM=mlterm
  the default.
* Sat Jan  8 2005 mfabian@suse.de
- update to 2.9.1.20050107.
* Wed Jan  5 2005 mfabian@suse.de
- update to 2.9.1.20050105.
- remove mlterm-configure.patch, and autoconf.patch
  (included upstream).
* Sun Sep  5 2004 mfabian@suse.de
- update to 2.8.0.2004090.
- enable uim.
- fix typo in man-page and compiler warning.
* Sun Sep  5 2004 mfabian@suse.de
- replace Kochi fonts with Sazanami fonts in config files.
- add entry for SCIM in /etc/X11/mlterm/xim.
* Tue Mar  2 2004 mfabian@suse.de
- update to 2.8.0.20040301.
- build against gtk2 instead of gtk1 now.
* Tue Feb 10 2004 mfabian@suse.de
- update to 2.8.0.20040210.
  fixes problems with dec special characters when starting mlterm
  like this "mlterm -A false -Y true" (Background was not redrawn).
* Tue Feb  3 2004 mfabian@suse.de
- update to 2.8.0.20040203.
- remove initial-font-size-out-of-range.patch (included upstream).
- make scrollbars selectable again and add the "pixmap_engine"
  scrollbar.
- mlterm-zoom is included in CVS now, drop extra tarball.
- add -fno-strict-aliasing
* Thu Jan 29 2004 mfabian@suse.de
- add initial-font-size-out-of-range.patch to fix crash when
  initial font size if out of range (e.g. "mlterm -R 1-10 -w 16").
- update to 2.8.0-20040129.
* Fri Jan 23 2004 mfabian@suse.de
- update to 2.8.0.20040123
- remove fontsize-range-segfault.patch and
  fontsize-range-enable.patch (included upstream).
* Mon Jan 19 2004 mfabian@suse.de
- update to 2.8.0.20040119
- fix segfault when only one argument is given to the "-R" option.
- make the "-R" option with correct parameters actually work.
- add mlterm-zoom-0.2.
- add default keybindings to increase/decrease fontsize with
  Shift+KP_Add/Shift+KP_Subtract respectively.
* Wed Jan 14 2004 mfabian@suse.de
- update to 2.8.0.20040109
- remove mlterm-enable-keypad.patch (included upstream).
- remove mlterm-default-xim.patch (included upstream).
* Tue Aug 19 2003 mfabian@suse.de
- use use_login_shell=false by default
- improve default font settings:
  * add 10x20 and 18x18ja font pair for iso10646-1 encoding
  * add "luxi mono" and "kochi gothic" font pair for iso10646-1
    encoding as a fallback for non-specified bitmap sizes
  * replace "kochi-mincho" by "kochi-gothic" (for Xft and core
    fonts)
  * add jiskan24 for jisx0208.1986 encoding (core fonts)
- add translations to desktop file.
* Sat Aug 16 2003 adrian@suse.de
- add desktop file
* Thu Jul  3 2003 mfabian@suse.de
- make KP_insert work as well.
* Wed Jul  2 2003 mfabian@suse.de
- make keys on keypad work when numlock is off.
* Mon Jun 30 2003 mfabian@suse.de
- remove w3mmlconfig, it's disabled anyway because of security
  concerns.
- make it build for older distributions as well
* Wed Jun 25 2003 mfabian@suse.de
- update to 2.7.0.
- remove mlterm-mlterm-menu.patch, mlterm-xft-null-pointer.patch,
  mlterm-libtool.patch:
  fixed upstream.
- add 10 pixel version of efont-unicode to the default font
  settings.
- update German translations (mlterm-po.patch).
* Mon Jun 23 2003 ro@suse.de
- fix build with current gettext/libtool
* Tue Apr 29 2003 mfabian@suse.de
- add "fontconfig fontconfig-devel" to neededforbuild
* Tue Mar 25 2003 mfabian@suse.de
- update to 2.6.3.20030325
  - cursor foreground and background colour can be selected now
  - setup changes done in the setup dialog can be saved now
  - new setup menu 'mlterm-menu' which is launched with
    "Ctrl+Left mouse button" by default
- mlterm-mlterm-menu.patch: use /etc/X11/mlterm/menu if
  ~/.mlterm/menu doesn't exist
- update German translation.
- mlterm-xft-null-pointer.patch: avoid crashes on 64 bit systems
  when using anti-aliasing.
- add compose_dec_special_font=true to /etc/X11/mlterm/main
* Mon Mar 24 2003 mfabian@suse.de
- add "kterm" entry to /etc/X11/mlterm/termcap to
  make the Delete key and the Backspace key behave the same way
  for TERM=kterm and TERM=mlterm by default.
* Mon Jan 20 2003 mfabian@suse.de
- update to 2.6.3
  - compose and dead keys work now
  - Xft2 support
  - annoying cut and paste bug is fixed (focusing the window
    and then pasting is now possible).
- remove mlterm-2.6.2-utmp.patch (included upstream)
- add local=en_GB.UTF-8 to /etc/X11/mlterm/xim, this input method
  is needed to use compose and dead keys
- add mlterm-default-xim.patch to make "local" the default input
  method if XMODIFIERS is not set, i.e. use compose and dead keys
  if XMODIFIERS is not set.
* Wed Nov 27 2002 mfabian@suse.de
- add expat to "# neededforbuild"
* Tue Nov 26 2002 mfabian@suse.de
- update to 2.6.2
- port mlterm-2.5.0-l10n.patch to 2.6.2 and update the
  German and Japanese translations
- UTMP support is broken again, but because of a different reason.
  make new patch: mlterm-2.6.2-utmp.patch.
- use better default font for ISO-8859-15 (without anti-aliasing)
* Wed Nov 13 2002 mfabian@suse.de
- fix for Bug #21078: gtk_set_locale must be called *before*
  gtk_init. Thanks to Koushi Takahashi <koushi@turbolinux.co.jp>
* Wed Oct  2 2002 mfabian@suse.de
- fix utempter support.
* Fri Sep  6 2002 mfabian@suse.de
- add /usr/share/locale/*/LC_MESSAGES/*.mo to filelist
- add /usr/share/man/man1/mlclient.1.gz to filelist
- add German translations
* Fri Sep  6 2002 koushi@turbolinux.co.jp
- modified prep procedure for non-root build
- add mlterm-2.5.0-l10n.patch
* Thu Jun 20 2002 mfabian@suse.de
- update to 2.5.0
  contains the following new features:
  - gdk-pixbuf as well as imlib is supported.(Thanks to
    Minami Hirokazu san)
  - mlterm can be built in other directories than the source tree.
    (Thanks to Nakada Nobuyoshi san)
  - BCE is supported.
  - mlterm is separated into vt100 core functions(mlterm/) and
    x window system specific functions(xwindow/), and mlterm
    window can be revived even if it is destroyed by a window
    manager.
  - UCS4 is used internally even if --enable-ucs4 option is
    not specified.
  - <KEY>=<OUTPUT STRING> format is supported in key config file.
  - mlcc is added. (Thanks to Minami Hirokazu san)
  - extra scrollbar plugins(athena,motif,mozmodern,next) are added.
    (Thanks to Sato Seiichi san)
  - 16 color support.
  - And many minor bugs are fixed.
- add default font settings for iso-8859-9 (Turkish)
* Thu Jun 13 2002 stepan@suse.de
- added lib64 patch
* Mon Apr  8 2002 mfabian@suse.de
- fix for new autoconf
* Wed Mar 20 2002 mfabian@suse.de
- add 'termtype=kterm' to /etc/X11/mlterm/main because this
  works better with mlterm. w3m sends 'ESC ( B ESC ) 0' to mlterm
  when 'termtype=xterm' is used because /usr/share/terminfo/x/xterm
  contains 'enacs=\E(B\E)0'. This causes the problem that
  Japanese kanji disappear after using w3mmlconfig.
* Fri Mar 15 2002 mfabian@suse.de
- fix problems with scroll_region using patches from upstream cvs
- add default font settings for iso8859-7 (Greek)
* Tue Mar  5 2002 mfabian@suse.de
- update to release 2.3.1
  contains the following fixes since the last update:
  - coredumps when scrolling while cursor is out of scroll region
    fixed
  - arrow icons in scroll bar fixed.
  - w3mmlconfig configuration tool updated.
  - mlclient with invalid options caused mlterm process to exit
  - man page updated
- add mlterm-2.3.1-ml-font-custom.patch from upstream cvs
  to avoid that the iso8859-1 font setting gets overwritten by the
  iso8859-15 font setting.
- add mlterm-2.3.1-ml-window.patch from upstream cvs to enable
  the use of iso8859-X encodings with X != 1 with anti-aliasing.
- simplify and improve default font settings,
  esp. add default font entries for iso8859-15 and iso8859-2
  and better defaults for UTF-8 with anti-aliasing
- add mlterm-2.3.1-man-page.patch to fix formatting errors in
  man-page
- add mlterm-2.3.1-ml-image-esc-j-and-wraparound.patch to make
  ESC [ J and linewrapping in 'cat' work correctly.
- remove mlterm-2.2.0.20020215-debug.patch, included upstream
* Sat Feb 23 2002 schwab@suse.de
- Fix missing declaration.
* Fri Feb 15 2002 mfabian@suse.de
- remove utempter patch, is now included upstream
- improve default font setup to pass the interactive terminal
  test of the LI18NUX200 specification
* Wed Feb 13 2002 mfabian@suse.de
- fix utempter support for the case of several terminals running
  under the same process
- some more fixes from CVS
* Tue Feb 12 2002 mfabian@suse.de
- upgrade to 2.2.0 + CVS fixes.
* Fri Nov 30 2001 mfabian@suse.de
- new package: mlterm, version 2.0.0
